@@ -1,6 +1,6 @@
 "phi2polychor.matrix" <-
 function(x,v) {
-if (!require(polycor)) {stop("I am sorry, you need to have loaded the polychor package")}
+if (!require(polycor)) {stop("I am sorry, you need to have loaded the polycor package")}
  sizex <- dim(x)[2]
  if (!is.vector(v)) v <- as.vector(v)
  nv <- length(v)
