@@ -1,5 +1,5 @@
 "principal" <-
-function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,missing=FALSE,impute="median", digits=2) {
+function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,missing=FALSE,impute="median") {
    cl <- match.call()
    n <- dim(r)[2]
   
@@ -22,7 +22,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
                      r <- r/(sds %o% sds)  }  #added June 9, 2008
     if (!residuals) { result <- list(values=c(rep(0,n)),rotation=rotate,n.obs=n.obs,communality=c(rep(0,n)),loadings=matrix(rep(0,n*n),ncol=n),fit=0,fit.off=0)} else { result <- list(values=c(rep(0,n)),rotation=rotate,n.obs=n.obs,communality=c(rep(0,n)),loadings=matrix(rep(0,n*n),ncol=n),residual=matrix(rep(0,n*n),ncol=n),fit=0,fit.off=0)}
     eigens <- eigen(r)    #call the eigen value decomposition routine
-    result$values <- round(eigens$values,digits)
+    result$values <- eigens$values
     eigens$values[ eigens$values < .Machine$double.eps] <-  .Machine$double.eps  #added May 14, 2009 to fix case of singular matrices
     loadings <- eigens$vectors %*% sqrt(diag(eigens$values))
    
@@ -34,6 +34,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
      #added January 19, 2009 to flip based upon colSums of loadings
     if (nfactors >1) {sign.tot <- vector(mode="numeric",length=nfactors)
                  sign.tot <- sign(colSums(loadings))
+                 sign.tot[sign.tot==0] <- 1
                  loadings <- loadings %*% diag(sign.tot)
      } else { if (sum(loadings) <0) {loadings <- -as.matrix(loadings)} else {loadings <- as.matrix(loadings)}
              colnames(loadings) <- "PC1" }
